@@ -1,7 +1,6 @@
 library(glmnet)
 
 test_that("tests for linear regression model", {
-
   n <- 100
   p <- 20
   X <- matrix(rnorm(n * p), nrow = n)
@@ -19,10 +18,14 @@ test_that("tests for linear regression model", {
   expect_error(predict(fit1, newx = X[10, ], type = "class"))
 
   # expect setting type with response and link would give the same results
-  expect_equal(predict(fit1, newx = X[10, ], type = "response"),
-               predict(fit1, newx = X[10, ], type = "link"))
-  expect_equal(predict(fit1, newx = X[10:15, ], type = "response"),
-               predict(fit1, newx = X[10:15, ], type = "link"))
+  expect_equal(
+    predict(fit1, newx = X[10, ], type = "response"),
+    predict(fit1, newx = X[10, ], type = "link")
+  )
+  expect_equal(
+    predict(fit1, newx = X[10:15, ], type = "response"),
+    predict(fit1, newx = X[10:15, ], type = "link")
+  )
 
   # test for a simplist case: set lambda equal to zero
   set.seed(1)
@@ -30,15 +33,21 @@ test_that("tests for linear regression model", {
   beta <- c(2, 1)
   y <- X %*% beta + rnorm(3, sd = .1)
   res1 <- sparsegl(X, y, lambda = 0, eps = 1e-8, maxit = 3e8)
-  res2 <- summary(lm(y~X))
+  res2 <- summary(lm(y ~ X))
 
   expect_equal(as.numeric(predict(res1, type = "coefficients")),
-               as.numeric(res2$coefficients[, 1]), tolerance = 1e-3)
+    as.numeric(res2$coefficients[, 1]),
+    tolerance = 1e-3
+  )
   expect_equal(predict(res1, type = "nonzero")[, 1], c(1, 2))
   expect_equal(predict(res1, newx = X, type = "response")[, 1],
-               as.numeric(predict(lm(y~X))), tolerance = 1e-3)
+    as.numeric(predict(lm(y ~ X))),
+    tolerance = 1e-3
+  )
   expect_equal(predict(res1, newx = X, type = "link")[, 1],
-               as.numeric(predict(lm(y~X))), tolerance = 1e-3)
+    as.numeric(predict(lm(y ~ X))),
+    tolerance = 1e-3
+  )
 })
 
 test_that("tests for logistic regression model", {
@@ -72,30 +81,41 @@ test_that("tests for logistic regression model", {
   # check whether y can be corrected if y is a numeric vector
   res3 <- sparsegl(X, y0, lambda = 0, family = "binomial", eps = 1e-8)
   chars <- y0
-  chars[chars == 0] <- 'a'
-  chars[chars == 1] <- 'b'
+  chars[chars == 0] <- "a"
+  chars[chars == 1] <- "b"
   res4 <- sparsegl(X, chars, lambda = 0, family = "binomial", eps = 1e-8)
 
   expect_equal(as.numeric(predict(res1, type = "coefficients")[, 1]),
-               as.numeric(c(res2$a0, res2$beta[, 1])), tolerance = 1e-3)
+    as.numeric(c(res2$a0, res2$beta[, 1])),
+    tolerance = 1e-3
+  )
   expect_equal(predict(res1, newx = X, type = "link"), predict(res2, newx = X),
-               tolerance = 1e-3)
+    tolerance = 1e-3
+  )
   expect_equal(predict(res1, newx = X, type = "response"),
-               1 / (1 + exp(-predict(res2, newx = X))), tolerance = 1e-3)
-  expect_equal(predict(res1, newx = X, type = "class"),
-               res2$classnames[ifelse(predict(res2, newx = X) > 0, 2, 1)])
+    1 / (1 + exp(-predict(res2, newx = X))),
+    tolerance = 1e-3
+  )
+  expect_equal(
+    predict(res1, newx = X, type = "class"),
+    res2$classnames[ifelse(predict(res2, newx = X) > 0, 2, 1)]
+  )
 
-  expect_equal(as.numeric(predict(res1, type = "coefficients")[, 1]),
-               as.numeric(predict(res3, type = "coefficients")[, 1]))
-  expect_equal(as.numeric(predict(res1, type = "coefficients")[, 1]),
-               as.numeric(predict(res4, type = "coefficients")[, 1]))
+  expect_equal(
+    as.numeric(predict(res1, type = "coefficients")[, 1]),
+    as.numeric(predict(res3, type = "coefficients")[, 1])
+  )
+  expect_equal(
+    as.numeric(predict(res1, type = "coefficients")[, 1]),
+    as.numeric(predict(res4, type = "coefficients")[, 1])
+  )
 })
 
 n <- 100
 p <- 20
 X <- matrix(rnorm(n * p), nrow = n)
 Xs <- X
-Xs[abs(X) < .05] = 0
+Xs[abs(X) < .05] <- 0
 Xs <- Matrix::Matrix(Xs, sparse = TRUE)
 eps <- rnorm(n)
 beta_star <- c(rep(5, 5), c(5, -5, 2, 0, 0), rep(-5, 5), rep(0, (p - 15)))
